@@ -1,4 +1,4 @@
-/* $Id: script_vehicle.cpp 24226 2012-05-12 07:22:40Z rubidium $ */
+/* $Id: script_vehicle.cpp 24424 2012-07-20 19:45:31Z rubidium $ */
 
 /*
  * This file is part of OpenTTD.
@@ -182,7 +182,7 @@
 /* static */ bool ScriptVehicle::IsInDepot(VehicleID vehicle_id)
 {
 	if (!IsValidVehicle(vehicle_id)) return false;
-	return ::Vehicle::Get(vehicle_id)->IsInDepot();
+	return ::Vehicle::Get(vehicle_id)->IsChainInDepot();
 }
 
 /* static */ bool ScriptVehicle::IsStoppedInDepot(VehicleID vehicle_id)
