@@ -1,4 +1,4 @@
-/* $Id: fullscreen.mm 23446 2011-12-08 18:13:29Z rubidium $ */
+/* $Id: fullscreen.mm 24603 2012-10-17 18:53:35Z rubidium $ */
 
 /*
  * This file is part of OpenTTD.
@@ -65,7 +65,7 @@ struct OTTD_QuartzGammaTable {
 @end
 
 @implementation NSScreen (NSScreenAccess)
-- (void) setFrame:(NSRect)frame;
+- (void) setFrame:(NSRect)frame
 {
 /* The 64 bits libraries don't seem to know about _frame, so this hack won't work. */
 #if !__LP64__
